package org.unix4j.unix.find;

import org.unix4j.command.AbstractCommand;
import org.unix4j.context.ExecutionContext;
import org.unix4j.line.Line;
import org.unix4j.line.SimpleLine;
import org.unix4j.processor.LineProcessor;
import org.unix4j.unix.Find;
import org.unix4j.util.FileUtil;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import static java.lang.String.format;

/**
 * Implementation of the {@link Find find} command.
 */
class FindCommand extends AbstractCommand<FindArguments> {
	public FindCommand(FindArguments arguments) {
		super(Find.NAME, arguments);
	}

	private List<File> getArgumentPaths(ExecutionContext context, FindArguments args) {
		if (args.isPathSet()) {
			return FileUtil.expandFiles(context.getCurrentDirectory(), args.getPath());
		} else {
			//no input files or paths ==> use just the current directory
			final ArrayList<File> list = new ArrayList<File>(1);
			list.add(context.getCurrentDirectory());
			return list;
		}
	}

	@Override
	public LineProcessor execute(final ExecutionContext context, final LineProcessor output) {
		final FindArguments args = getArguments(context);
		final List<File> paths = getArgumentPaths(context, args);
		return new LineProcessor() {
			@Override
			public boolean processLine(Line line) {
				return false;//we ignore all input
			}
			@Override
			public void finish() {
				for(final File path: paths){
					final boolean keepGoing;

					if(!path.exists()){
						keepGoing = output.processLine(new SimpleLine(format("find: `%s': No such file or directory", path)));
					} else if(path.isDirectory()){
						keepGoing = listFiles(path, path, output, args);
					} else {
						keepGoing = output.processLine(new SimpleLine(path.getPath()));
					}
					if(!keepGoing){
						break;
					}
				}
				output.finish();
			}
		};
	}

	private boolean listFiles(File relativeTo, File parent, LineProcessor output, FindArguments args) {
		final boolean recurseSubdirs = true;
		final List<File> files = FileUtil.toList(parent.listFiles());
		if(files.size() == 0) return true;

		//print directory files and recurse if necessary
		for (File file : files) {
			//System.out.println("Examining file: " + file.getAbsolutePath());
			if (!file.isHidden()) {
				if (file.isDirectory() && recurseSubdirs) {
					if (!listFiles(relativeTo, file, output, args)) {
						return false;
					}
				} else {
					if(!output.processLine(new SimpleLine(FileUtil.getRelativePath(relativeTo, file)))){
						return false;
					}
				}
			}
		}
		return true;//we want more output
	}
}