package org.unix4j.unix.from;


import org.unix4j.command.Arguments;
import org.unix4j.context.ExecutionContext;
import org.unix4j.util.ArrayUtil;

import org.unix4j.unix.From;

/**
 * Arguments and options for the {@link From from} command.
 */
public final class FromArguments implements Arguments<FromArguments> {
	

	
	// operand: <input>
	private org.unix4j.io.Input input;
	private boolean inputIsSet = false;
	
	/**
	 * Constructor to use if no options are specified.
	 */
	public FromArguments() {
		super();
	}
	
	@Override
	public FromArguments getForContext(ExecutionContext context) {
		if (context == null) {
			throw new NullPointerException("context cannot be null");
		}
		//no String... args for this command, hence nothing to resolve
		return this;
	}
	
	/**
	 * Returns {@code <input>}: the input object to read from
	 * 
	 * @return the {@code <input>} operand value
	 * @throws IllegalStateException if this operand has never been set
	 */
	public org.unix4j.io.Input getInput() {
		if (inputIsSet) {
			return input;
		}
		throw new IllegalStateException("operand has not been set: " + input);
	}

	/**
	 * Returns true if the {@code <input>} operand has been set. 
	 * <p>
	 * Note that this method returns true if {@link #setInput(org.unix4j.io.Input)}
	 * also if null was passed to the method.
	 * 
	 * @return	true if the setter for the {@code <input>} operand has 
	 * 			been called at least once
	 */
	public boolean isInputSet() {
		return inputIsSet;
	}
	/**
	 * Sets {@code <input>}: the input object to read from
	 * 
	 * @param input the value for the {@code <input>} operand
	 */
	public void setInput(org.unix4j.io.Input input) {
		this.input = input;
		this.inputIsSet = true;
	}
	

	@Override
	public String toString() {
		// ok, we have options or arguments or both
		final StringBuilder sb = new StringBuilder();

{
			// operand: <input>
			if (inputIsSet) {
				if (sb.length() > 0) sb.append(' ');
				sb.append("--").append("input");
				sb.append(" ").append(toString(getInput()));
			}
		}
		
		return sb.toString();
	}
	private static String toString(Object value) {
		if (value != null && value.getClass().isArray()) {
			return ArrayUtil.toString(value);
		}
		return String.valueOf(value);
	}
}
