package org.unix4j.unix.sed;

import org.unix4j.unix.Sed;

/**
 * Factory for the {@link Sed sed} command returning 
 * a new command instance from every signature method.
 */
public final class SedFactory implements Sed.Interface<SedCommand> {
	
	/**
	 * The singleton instance of this factory.
	 */
	public static final SedFactory INSTANCE = new SedFactory();

	/**
	 * Private, only used to create singleton instance.
	 */
	private SedFactory() {
		super();
	}

	@Override
	public SedCommand sed(String... args) {
		final SedArguments sedArgs = new SedArguments(args);
		return new SedCommand(sedArgs);
	}

	@Override
	public SedCommand sed(String script) {
		final SedArguments sedArgs = new SedArguments();
		sedArgs.setScript(script);
		return new SedCommand(sedArgs);
	}
}
